@@ -174,7 +174,7 @@ impl ConfigSerializer {
             let mut creators = vec![];
             creators.reserve(creator_count as usize);
 
-            for _ in 0..matcher_count {
+            for _ in 0..creator_count {
                 let extractor_code = read_integer_from_vec!(data, offset, u16);
                 let extractor = Self::read_extractor_from_vec(data, &mut offset, extractor_code)?;
 
@@ -222,6 +222,27 @@ impl ConfigSerializer {
             offset,
             extractor_code
         );
+        impl_item_read!(
+            EVENT_PRODUCER_ADDRESS_EXTRACTOR_CODE,
+            EventProducerAddressExtractor,
+            data,
+            offset,
+            extractor_code
+        );
+        impl_item_read!(
+            MESSAGE_CODE_EXTRACTOR_CODE,
+            MessageCodeExtractor,
+            data,
+            offset,
+            extractor_code
+        );
+        impl_item_read!(
+            MESSAGE_VALUE_EXTRACTOR_CODE,
+            MessageValueExtractor,
+            data,
+            offset,
+            extractor_code
+        );
         Err(ConfigSerializerError::UnknownExtractor)
     }
 
@@ -237,6 +258,24 @@ impl ConfigSerializer {
             extractor
         );
         impl_item_write!(PACKET_EXTRACTOR_CODE, PacketExtractor, data, extractor);
+        impl_item_write!(
+            EVENT_PRODUCER_ADDRESS_EXTRACTOR_CODE,
+            EventProducerAddressExtractor,
+            data,
+            extractor
+        );
+        impl_item_write!(
+            MESSAGE_CODE_EXTRACTOR_CODE,
+            MessageCodeExtractor,
+            data,
+            extractor
+        );
+        impl_item_write!(
+            MESSAGE_VALUE_EXTRACTOR_CODE,
+            MessageValueExtractor,
+            data,
+            extractor
+        );
         Err(ConfigSerializerError::UnknownExtractor)
     }
 
@@ -418,7 +457,7 @@ mod tests {
     use super::*;
 
     #[test]
-    fn serialize_config_serializer_test() {
+    fn serialize_test() {
         let mut initial_state = BTreeMap::new();
         initial_state.insert(0, StateValue::U8(0xff));
 
@@ -463,7 +502,7 @@ mod tests {
     }
 
     #[test]
-    fn deserialize_config_serializer_wrong_size_test() {
+    fn deserialize_wrong_size_test() {
         let data = vec![];
 
         let err = ConfigSerializer::deserialize(&data).unwrap_err();
@@ -472,7 +511,7 @@ mod tests {
     }
 
     #[test]
-    fn deserialize_config_serializer_empty_test() {
+    fn deserialize_empty_test() {
         let data = vec![
             0x00, 0x00, 0x00, 0x00, // initial state count
             0x00, 0x00, 0x00, 0x00, // event processor count
@@ -485,7 +524,7 @@ mod tests {
     }
 
     #[test]
-    fn deserialize_config_serializer_test() {
+    fn deserialize_test() {
         let data = vec![
             0x00, 0x00, 0x00, 0x01, // initial state count
             0x00, 0x00, 0x00, 0x00, // state_index
